@@ -1,7 +1,7 @@
 import asyncio
 
 from .....index import Index
-from .....storage.collections import ExperimentStorageCollection
+from .....submission.collections import SubmissionCollection
 from .subscription_type import subscription
 
 
@@ -11,24 +11,24 @@ async def index_generator(obj, info, index, limit=10):
     index = Index.get(index)
 
     since = None
-    updates = ExperimentStorageCollection()
+    updates = SubmissionCollection()
     while True:
         updates = updates.filter(lambda x: x.is_finished())
-        experiments = index.find_latest(limit=limit, since=since)
-        if len(experiments) > 0:
-            since = experiments.first().started_at
+        submissions = index.find_latest(limit=limit, since=since)
+        if len(submissions) > 0:
+            since = submissions.first().started_at
 
-        if len(experiments) > 0 or len(updates) > 0:
-            yield experiments, updates
+        if len(submissions) > 0 or len(updates) > 0:
+            yield submissions, updates
 
-        updates.merge(experiments)
+        updates.merge(submissions)
 
         await asyncio.sleep(polling_interval)
 
 
 class IndexSubscriptionDelta:
-    def __init__(self, experiments, updates):
-        self.experiments = experiments
+    def __init__(self, submissions, updates):
+        self.submissions = submissions
         self.updates = updates
 
 
